==> config_widget-0.0.6.tar.gz: bin/analyze/config.dart <==
import 'package:analyzer/dart/analysis/analysis_context.dart';
import 'package:analyzer/dart/analysis/analysis_context_collection.dart';

import 'analyze_single_file.dart';
import 'config_widget_package.dart';
import 'write_file.dart';
import 'package:args/command_runner.dart';

class CreateCommand extends Command {
  @override
  final name = 'config';

  @override
  final description = 'Config widget Analyze';

  CreateCommand() {
    // [argParser] is automatically created by the parent class.
    argParser.addOption('root_path');
  }

  // [run] may also return a Future.
  Future<void> run() async {
    print(argResults['root_path']);
    await runAnalyze(rootPath: argResults['root_path']);
  }
}

void main(List<String> arguments) async {
  if (isTest) {
    runAnalyze();
  } else {
    CommandRunner runner = CommandRunner('config', 'Config widget Analyze Tools.')..addCommand(CreateCommand());
    await runner.run(arguments);
  }
}

Future<void> runAnalyze({String rootPath}) async {
  List<String> includedPaths = await containConfigWidgetPackagePath(rootPath);

  DateTime begin = DateTime.now();
  print('正在分析中。。。。');
  AnalysisContextCollection collection = AnalysisContextCollection(includedPaths: includedPaths);

  Map<String, dynamic> map = await analyzeSomeFiles(collection, includedPaths);
  writeToCatchFile(map);

  print('完成用时 ${DateTime.now().difference(begin)}');
}

Future<Map<String, dynamic>> analyzeSomeFiles(AnalysisContextCollection collection, List<String> includedPaths) async {
  Map<String, dynamic> catchMap = {};
  for (String path in includedPaths) {
    AnalysisContext context = collection.contextFor(path);
    List<Map<String, dynamic>> map = await analyzeSingleFile(context, path);

    if (map != null && map.isNotEmpty) {
      map.forEach((element) {
        catchMap.addAll(element);
      });
    }
  }
  return catchMap;
}

==> config_widget-0.0.7.tar.gz: bin/analyze/config.dart <==
import 'package:analyzer/dart/analysis/analysis_context.dart';
import 'package:analyzer/dart/analysis/analysis_context_collection.dart';

import 'analyze_single_file.dart';
import 'config_widget_package.dart';
import 'write_file.dart';
import 'package:args/command_runner.dart';

class CreateCommand extends Command {
  @override
  final name = 'config';

  @override
  final description = 'Config widget Analyze';

  CreateCommand() {
    // [argParser] is automatically created by the parent class.
    argParser.addOption('root_path');
  }

  // [run] may also return a Future.
  Future<void> run() async {
    print(argResults['root_path']);
    await runAnalyze(rootPath: argResults['root_path']);
  }
}

void main(List<String> arguments) async {
  if (isTest) {
    runAnalyze();
  } else {
    CommandRunner runner = CommandRunner('config', 'Config widget Analyze Tools.')..addCommand(CreateCommand());
    await runner.run(arguments);
  }
}

Future<void> runAnalyze({String rootPath}) async {
  List<String> includedPaths = await containConfigWidgetPackagePath(rootPath);

  DateTime begin = DateTime.now();
  print('正在分析中。。。。');
  AnalysisContextCollection collection = AnalysisContextCollection(includedPaths: includedPaths);

  Map<String, dynamic> map = await analyzeSomeFiles(collection, includedPaths);
  writeToCatchFile(rootPath, map);

  print('完成用时 ${DateTime.now().difference(begin)}');
}

Future<Map<String, dynamic>> analyzeSomeFiles(AnalysisContextCollection collection, List<String> includedPaths) async {
  Map<String, dynamic> catchMap = {};
  for (String path in includedPaths) {
    AnalysisContext context = collection.contextFor(path);
    List<Map<String, dynamic>> map = await analyzeSingleFile(context, path);

    if (map != null && map.isNotEmpty) {
      map.forEach((element) {
        catchMap.addAll(element);
      });
    }
  }
  return catchMap;
}
